@@ -1,5 +1,5 @@
 /*
- * Copyright 2016-2017, Intel Corporation
+ * Copyright 2016-2019, Intel Corporation
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -241,7 +241,7 @@ struct rpmem_fip_lane_attr {
 	size_t n_per_cq; /* number of entries per lane in completion queue */
 };
 
-static struct rpmem_fip_lane_attr
+static const struct rpmem_fip_lane_attr
 rpmem_fip_lane_attrs[MAX_RPMEM_FIP_NODE][MAX_RPMEM_PM] = {
 	[RPMEM_FIP_NODE_CLIENT][RPMEM_PM_GPSPM] = {
 		.n_per_sq = 2, /* WRITE + SEND */
@@ -276,7 +276,8 @@ rpmem_fip_cq_size(enum rpmem_persist_method pm, enum rpmem_fip_node node)
 	RPMEMC_ASSERT(pm < MAX_RPMEM_PM);
 	RPMEMC_ASSERT(node < MAX_RPMEM_FIP_NODE);
 
-	struct rpmem_fip_lane_attr *attr = &rpmem_fip_lane_attrs[node][pm];
+	const struct rpmem_fip_lane_attr *attr =
+			&rpmem_fip_lane_attrs[node][pm];
 	return attr->n_per_cq ? : 1;
 }
 
@@ -290,7 +291,8 @@ rpmem_fip_tx_size(enum rpmem_persist_method pm, enum rpmem_fip_node node)
 	RPMEMC_ASSERT(pm < MAX_RPMEM_PM);
 	RPMEMC_ASSERT(node < MAX_RPMEM_FIP_NODE);
 
-	struct rpmem_fip_lane_attr *attr = &rpmem_fip_lane_attrs[node][pm];
+	const struct rpmem_fip_lane_attr *attr =
+			&rpmem_fip_lane_attrs[node][pm];
 	return attr->n_per_sq ? : 1;
 }
 
@@ -304,7 +306,8 @@ rpmem_fip_rx_size(enum rpmem_persist_method pm, enum rpmem_fip_node node)
 	RPMEMC_ASSERT(pm < MAX_RPMEM_PM);
 	RPMEMC_ASSERT(node < MAX_RPMEM_FIP_NODE);
 
-	struct rpmem_fip_lane_attr *attr = &rpmem_fip_lane_attrs[node][pm];
+	const struct rpmem_fip_lane_attr *attr =
+			&rpmem_fip_lane_attrs[node][pm];
 	return attr->n_per_rq ? : 1;
 }
 
